Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(117)

Unified Diff: components/data_reduction_proxy/core/browser/data_reduction_proxy_config.h

Issue 2351513002: net: rename BoundNetLog to NetLogWithSource (Closed)
Patch Set: one more fix, content bound_net_log_ Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/data_reduction_proxy/core/browser/data_reduction_proxy_config.h
diff --git a/components/data_reduction_proxy/core/browser/data_reduction_proxy_config.h b/components/data_reduction_proxy/core/browser/data_reduction_proxy_config.h
index c7f7e8252a2fbca65e750cba9fccd62e3bff1675..970c64d0077e3fff156119cc5a1c2dbb89b00574 100644
--- a/components/data_reduction_proxy/core/browser/data_reduction_proxy_config.h
+++ b/components/data_reduction_proxy/core/browser/data_reduction_proxy_config.h
@@ -93,7 +93,8 @@ class DataReductionProxyConfig
// of the |DataReductionProxyConfig| instance, with the exception of
// |config_values| which is owned by |this|. |event_creator| is used for
// logging the start and end of a secure proxy check; |net_log| is used to
// create a net::BoundNetLog for correlating the start and end of the check.
sdefresne 2016/09/22 13:27:18 nit: can you rewrap this comment?
// |config_values| contains the Data Reduction Proxy configuration values.
// |configurator| is the target for a configuration update.
DataReductionProxyConfig(
@@ -327,12 +328,13 @@ class DataReductionProxyConfig
scoped_refptr<base::SingleThreadTaskRunner> io_task_runner_;
// The caller must ensure that the |net_log_|, if set, outlives this instance.
- // It is used to create new instances of |bound_net_log_| on secure proxy
- // checks. |bound_net_log_| permits the correlation of the begin and end
+ // It is used to create new instances of |net_log_with_source_| on secure
+ // proxy
sdefresne 2016/09/22 13:27:18 nit: can you rewrap this comment?
+ // checks. |net_log_with_source_| permits the correlation of the begin and end
// phases of a given secure proxy check, and a new one is created for each
// secure proxy check (with |net_log_| as a parameter).
net::NetLog* net_log_;
- net::BoundNetLog bound_net_log_;
+ net::NetLogWithSource net_log_with_source_;
// The caller must ensure that the |configurator_| outlives this instance.
DataReductionProxyConfigurator* configurator_;
@@ -93,7 +93,8 @@ class DataReductionProxyConfig
// |config_values| which is owned by |this|. |event_creator| is used for
// logging the start and end of a secure proxy check; |net_log| is used to
- // create a net::BoundNetLog for correlating the start and end of the check.
+ // create a net::NetLogWithSource for correlating the start and end of the
+ // check.
sdefresne 2016/09/22 13:27:18 nit: can you rewrap this comment?
// |config_values| contains the Data Reduction Proxy configuration values.

Powered by Google App Engine
This is Rietveld 408576698